@@ -1,8 +1,18 @@
 class Table(object):
+    """The Table class is the basic table class."""
     name = ""
     table_content = [[]]
+    """
+    The table_content holds the table data
+    """
 
     def display(self, divider=", "):
+        """
+        Use display for pretty-printing to the console.
+
+        :param divider: Used to customize the divider between the columns.
+        :return: A string with a pretty-print of your table.
+        """
         string = ""
         for row in self.table_content:
             for record in range(int(len(row))):
@@ -12,9 +22,12 @@ class Table(object):
             string = string + "\n"
         return string
 
-        return string
-
     def get_col(self, col_name):
+        """
+        Used to get all data in one column.
+        :param col_name: The name of the column you wish to get.
+        :return: A list of all data in one column.
+        """
         col_position = self.table_content[0].index(col_name)
 
         col = []
@@ -25,6 +38,14 @@ class Table(object):
         return col
 
     def add_expand(self, new_col_name, old_col_name, action, value):
+        """
+        Used to add a column that is based on another column.
+        :param new_col_name: The name for you new column.
+        :param old_col_name: The name for the column you wish to expand from.
+        :param action: What change you want from your old column to your new column. Can be "+" (or "add"), "-" (or subtract), "*" (or multiply), "/" (or divide), or "join" for combining two strings.
+        :param value: What difference from the old column you wish to make. For example, if your action was "*", then and your value was "2", everything would get multiplied by two.
+        :return:
+        """
         result = []
 
 
@@ -45,14 +66,25 @@ class Table(object):
                 result.append(str(i) + str(value))
 
             else:
-                raise Exception(f"Unkown action '{action}'")
+                raise Exception(f"Unknown action '{action}'")
 
         self.add_col(new_col_name, result)
 
     def add_row(self, new_content):
+        """
+        Used to add a row to your table.
+        :param new_content: A list of the row you wish to add.
+        :return:
+        """
         self.table_content.append(new_content)
 
     def add_col(self, col_name, default_value=""):
+        """
+        Used to add a column to your table.
+        :param col_name: The name of your new column.
+        :param default_value: The default value all your new records will get in that column when created or a list of specific values that will go into your column.
+        :return:
+        """
         self.table_content[0].append(col_name)
 
         for i in range(int(len(self.table_content)) - 1):
@@ -63,9 +95,27 @@ class Table(object):
                 self.table_content[i + 1].append(default_value[i])
 
     def edit_row(self, row_num, col_name, new_value):
+        """
+        Used to edit a record of your table.
+        :param row_num: The row number of the record that you wish to edit.
+        :param col_name: The column name of your record that you wish to edit.
+        :param new_value: The rew record value.
+        :return:
+        """
         self.table_content[row_num][self.table_content[0].index(col_name)] = new_value
 
-    def filter(self, col_name, value, type="exact", search_start=1, search_end="END", add_headers_to_result=True, legecy=False):
+    def filter(self, col_name, value, type="exact", search_start=1, search_end="END", add_headers_to_result=True, legacy=False):
+        """
+        Uesed to filter your table.
+        :param col_name: The column you wish to use to filter.
+        :param value: The value you wish to use to filter with.
+        :param type: The filter type. Can be "exact" (same), "iexact" (not case-sensitive), "greaterthan", or "lessthan".
+        :param search_start: The row to start filtering at.
+        :param search_end: The row to stop filtering at. Type "END" to stop at the end.
+        :param add_headers_to_result: If True, your table headers will be included in the result.
+        :param legacy: If True, will return a list instead of a Table object.
+        :return: A Table object with the filtered results (unless specified otherwise).
+        """
         if search_end == "END":
             search_end = int(len(self.table_content))
 
@@ -93,7 +143,7 @@ class Table(object):
         if add_headers_to_result:
             result_list.insert(0, self.table_content[0])
 
-        if legecy:
+        if legacy:
             return result_list
         else:
             temp_table = Table()
